==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/hybridcompute/kotlin/inputs/MachineExtensionInstanceViewStatusArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridcompute.kotlin.inputs

import com.pulumi.azurenative.hybridcompute.inputs.MachineExtensionInstanceViewStatusArgs.builder
import com.pulumi.azurenative.hybridcompute.kotlin.enums.StatusLevelTypes
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Instance view status.
 * @property code The status code.
 * @property displayStatus The short localizable label for the status.
 * @property level The level code.
 * @property message The detailed status message, including for alerts and error messages.
 * @property time The time of the status.
 */
public data class MachineExtensionInstanceViewStatusArgs(
    public val code: Output<String>? = null,
    public val displayStatus: Output<String>? = null,
    public val level: Output<Either<String, StatusLevelTypes>>? = null,
    public val message: Output<String>? = null,
    public val time: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.hybridcompute.inputs.MachineExtensionInstanceViewStatusArgs> {
    override fun toJava():
        com.pulumi.azurenative.hybridcompute.inputs.MachineExtensionInstanceViewStatusArgs =
        com.pulumi.azurenative.hybridcompute.inputs.MachineExtensionInstanceViewStatusArgs.builder()
            .code(code?.applyValue({ args0 -> args0 }))
            .displayStatus(displayStatus?.applyValue({ args0 -> args0 }))
            .level(
                level?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .message(message?.applyValue({ args0 -> args0 }))
            .time(time?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MachineExtensionInstanceViewStatusArgs].
 */
@PulumiTagMarker
public class MachineExtensionInstanceViewStatusArgsBuilder internal constructor() {
    private var code: Output<String>? = null

    private var displayStatus: Output<String>? = null

    private var level: Output<Either<String, StatusLevelTypes>>? = null

    private var message: Output<String>? = null

    private var time: Output<String>? = null

    /**
     * @param value The status code.
     */
    @JvmName("kaapdpjlmusjhimb")
    public suspend fun code(`value`: Output<String>) {
        this.code = value
    }

    /**
     * @param value The short localizable label for the status.
     */
    @JvmName("tkxyerckaormmily")
    public suspend fun displayStatus(`value`: Output<String>) {
        this.displayStatus = value
    }

    /**
     * @param value The level code.
     */
    @JvmName("mhyboqbpcnjnhfnj")
    public suspend fun level(`value`: Output<Either<String, StatusLevelTypes>>) {
        this.level = value
    }

    /**
     * @param value The detailed status message, including for alerts and error messages.
     */
    @JvmName("mtecliysgowarbec")
    public suspend fun message(`value`: Output<String>) {
        this.message = value
    }

    /**
     * @param value The time of the status.
     */
    @JvmName("ipdabikabrstlpau")
    public suspend fun time(`value`: Output<String>) {
        this.time = value
    }

    /**
     * @param value The status code.
     */
    @JvmName("cqfalqwqfcbjwbha")
    public suspend fun code(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.code = mapped
    }

    /**
     * @param value The short localizable label for the status.
     */
    @JvmName("emhjswpdhdfomrkw")
    public suspend fun displayStatus(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.displayStatus = mapped
    }

    /**
     * @param value The level code.
     */
    @JvmName("mevofaytvfdlqknl")
    public suspend fun level(`value`: Either<String, StatusLevelTypes>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.level = mapped
    }

    /**
     * @param value The level code.
     */
    @JvmName("bwwgkpwfipqtlsse")
    public fun level(`value`: String) {
        val toBeMapped = Either.ofLeft<String, StatusLevelTypes>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.level = mapped
    }

    /**
     * @param value The level code.
     */
    @JvmName("ajjuuxtnuxyiknsx")
    public fun level(`value`: StatusLevelTypes) {
        val toBeMapped = Either.ofRight<String, StatusLevelTypes>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.level = mapped
    }

    /**
     * @param value The detailed status message, including for alerts and error messages.
     */
    @JvmName("xennlrujortpfdut")
    public suspend fun message(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.message = mapped
    }

    /**
     * @param value The time of the status.
     */
    @JvmName("katbphrsoysuemej")
    public suspend fun time(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.time = mapped
    }

    internal fun build(): MachineExtensionInstanceViewStatusArgs =
        MachineExtensionInstanceViewStatusArgs(
            code = code,
            displayStatus = displayStatus,
            level = level,
            message = message,
            time = time,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/hybridcompute/kotlin/inputs/MachineExtensionInstanceViewStatusArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridcompute.kotlin.inputs

import com.pulumi.azurenative.hybridcompute.inputs.MachineExtensionInstanceViewStatusArgs.builder
import com.pulumi.azurenative.hybridcompute.kotlin.enums.StatusLevelTypes
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Instance view status.
 * @property code The status code.
 * @property displayStatus The short localizable label for the status.
 * @property level The level code.
 * @property message The detailed status message, including for alerts and error messages.
 * @property time The time of the status.
 */
public data class MachineExtensionInstanceViewStatusArgs(
    public val code: Output<String>? = null,
    public val displayStatus: Output<String>? = null,
    public val level: Output<Either<String, StatusLevelTypes>>? = null,
    public val message: Output<String>? = null,
    public val time: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.hybridcompute.inputs.MachineExtensionInstanceViewStatusArgs> {
    override fun toJava():
        com.pulumi.azurenative.hybridcompute.inputs.MachineExtensionInstanceViewStatusArgs =
        com.pulumi.azurenative.hybridcompute.inputs.MachineExtensionInstanceViewStatusArgs.builder()
            .code(code?.applyValue({ args0 -> args0 }))
            .displayStatus(displayStatus?.applyValue({ args0 -> args0 }))
            .level(
                level?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .message(message?.applyValue({ args0 -> args0 }))
            .time(time?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MachineExtensionInstanceViewStatusArgs].
 */
@PulumiTagMarker
public class MachineExtensionInstanceViewStatusArgsBuilder internal constructor() {
    private var code: Output<String>? = null

    private var displayStatus: Output<String>? = null

    private var level: Output<Either<String, StatusLevelTypes>>? = null

    private var message: Output<String>? = null

    private var time: Output<String>? = null

    /**
     * @param value The status code.
     */
    @JvmName("kloxvmvmhwgxkeuv")
    public suspend fun code(`value`: Output<String>) {
        this.code = value
    }

    /**
     * @param value The short localizable label for the status.
     */
    @JvmName("vwpeqpyniecfbtdm")
    public suspend fun displayStatus(`value`: Output<String>) {
        this.displayStatus = value
    }

    /**
     * @param value The level code.
     */
    @JvmName("lbqxrdumoynbdqqk")
    public suspend fun level(`value`: Output<Either<String, StatusLevelTypes>>) {
        this.level = value
    }

    /**
     * @param value The detailed status message, including for alerts and error messages.
     */
    @JvmName("kujcuqqffoppphdu")
    public suspend fun message(`value`: Output<String>) {
        this.message = value
    }

    /**
     * @param value The time of the status.
     */
    @JvmName("enjubryuhreulkhr")
    public suspend fun time(`value`: Output<String>) {
        this.time = value
    }

    /**
     * @param value The status code.
     */
    @JvmName("cjngoekopsgebjle")
    public suspend fun code(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.code = mapped
    }

    /**
     * @param value The short localizable label for the status.
     */
    @JvmName("ghctfqjiktgkfssw")
    public suspend fun displayStatus(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.displayStatus = mapped
    }

    /**
     * @param value The level code.
     */
    @JvmName("ncslpkirxwpravxa")
    public suspend fun level(`value`: Either<String, StatusLevelTypes>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.level = mapped
    }

    /**
     * @param value The level code.
     */
    @JvmName("hbrwxrvamwteqaeu")
    public fun level(`value`: String) {
        val toBeMapped = Either.ofLeft<String, StatusLevelTypes>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.level = mapped
    }

    /**
     * @param value The level code.
     */
    @JvmName("datfcpdlhatpitjq")
    public fun level(`value`: StatusLevelTypes) {
        val toBeMapped = Either.ofRight<String, StatusLevelTypes>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.level = mapped
    }

    /**
     * @param value The detailed status message, including for alerts and error messages.
     */
    @JvmName("jgimuqpulmptbosx")
    public suspend fun message(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.message = mapped
    }

    /**
     * @param value The time of the status.
     */
    @JvmName("lyscjseogasrlhom")
    public suspend fun time(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.time = mapped
    }

    internal fun build(): MachineExtensionInstanceViewStatusArgs =
        MachineExtensionInstanceViewStatusArgs(
            code = code,
            displayStatus = displayStatus,
            level = level,
            message = message,
            time = time,
        )
}
